@@ -40,7 +40,7 @@ class RabbitClient:
         self.port = port or 5762
         self.default_exchange = default_exchange or ''
         self.virtual_host = virtual_host or '/'
-        log.info('RabbitApp configured.')
+        log.info('RabbitClient configured.')
         log.debug('host=%s', self.host)
         log.debug('port=%s', self.port)
         log.debug('default_exchange=%s', self.default_exchange)
@@ -287,8 +287,8 @@ class RabbitClient:
     ) -> Callable:
         """Decorate a callable to generate queues and consume from them.
 
-        A new non-durable, auto-deleting queue will be generated for
-        each provided routing key.
+        A new non-durable, auto-deleting, exclusive queue will be
+        generated for each provided routing key.
         The decorated function can have as parameters, any or all of,
         message body, method, and properties.
 
@@ -304,6 +304,7 @@ class RabbitClient:
         """
         self._reset_if_lost()
         rks = [routing_keys] if isinstance(routing_keys, str) else routing_keys
+        exchange = exchange or self.default_exchange
 
         # If a connection is lost, the auto-deleting queues will all be
         # gone so reconnecting won't work. We pass the consume logic
@@ -315,6 +316,7 @@ class RabbitClient:
                 log.debug('Declaring new queue top bind to [%s].', key)
                 q = channel.queue_declare(
                     queue='',
+                    exclusive=True,
                     auto_delete=True,
                     arguments=declare_arguments
                 ).method.queue
@@ -336,7 +338,7 @@ class RabbitClient:
             thread.start()
             for rk in rks:
                 log.info(
-                    'Thread spawned for [%s] to consume a queue on [%s - %s]',
+                    'Thread spawned for [%s] to consume a queue on [%s: %s]',
                     fun.__name__,
                     exchange,
                     rk
@@ -473,6 +475,8 @@ def _listen(
         try:
             resp = fun(**kwargs)
             if properties.reply_to:
+                if resp is None:
+                    resp = b''
                 ch.basic_publish(
                     exchange='',
                     routing_key=properties.reply_to,
