@@ -8,7 +8,7 @@ from typing import Any
 from chromaformatter import ChromaFormatter
 from dataclasses_json import dataclass_json
 
-from snacks.rabbit import RabbitApp
+from snacks.rabbit import RabbitClient
 
 log = logging.getLogger('snacks')
 log.setLevel(logging.INFO)
@@ -24,7 +24,7 @@ log.addHandler(stream_handler)
 log.setLevel(logging.DEBUG)
 
 # Initial setup of configuration and Rabbit class.
-rabbit = RabbitApp(
+rabbit = RabbitClient(
     host='localhost',
     port=5672,
     default_exchange='snacks',
